From e65c789344951139b9c741c34c71af746c465f13 Mon Sep 17 00:00:00 2001
From: "Bryn M. Reeves" <bmr@redhat.com>
Date: Tue, 10 Jun 2014 20:54:09 +0100
Subject: [PATCH 12/17] [keepalived] new plugin

Fixes #302.

Signed-off-by: Bryn M. Reeves <bmr@redhat.com>
---
 sos/plugins/keepalived.py | 33 +++++++++++++++++++++++++++++++++
 1 file changed, 33 insertions(+)
 create mode 100644 sos/plugins/keepalived.py

diff --git a/sos/plugins/keepalived.py b/sos/plugins/keepalived.py
new file mode 100644
index 0000000..e79778c
--- /dev/null
+++ b/sos/plugins/keepalived.py
@@ -0,0 +1,33 @@
+## Copyright (C) 2014 Red Hat, Inc. Jamie Bainbridge <jbainbri@redhat.com>
+## Copyright (C) 2014 Red Hat, Inc. Bryn M. Reeves <bmr@redhat.com>
+### This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+from sos.plugins import Plugin, RedHatPlugin
+
+class Keepalived(Plugin, RedHatPlugin):
+    """Keepalived information
+    """
+
+    plugin_name = 'keepalived'
+
+    packages = ('keepalived',)
+
+    def setup(self):
+        self.add_copy_specs([
+            "/etc/keepalived/keepalived.conf",
+            "/etc/sysconfig/keepalived"
+        ])
+
+# vim: et ts=4 sw=4
-- 
1.9.3

From bb31aa99bfab3a8a3c75875f83bb6a9104f7db80 Mon Sep 17 00:00:00 2001
From: "Bryn M. Reeves" <bmr@redhat.com>
Date: Tue, 10 Jun 2014 20:56:55 +0100
Subject: [PATCH 13/17] [ipvs,keepalived] fix misleading copyright header

I've been using firewalld.py as a template for new plugins; forgot
to fix the copyright header to have the correct authorship.

Signed-off-by: Bryn M. Reeves <bmr@redhat.com>

Conflicts:
	sos/plugins/ipvs.py
---
 sos/plugins/ipvs.py       | 28 ++++++++++++++++++++++++++++
 sos/plugins/keepalived.py | 13 ++++---------
 2 files changed, 32 insertions(+), 9 deletions(-)
 create mode 100644 sos/plugins/ipvs.py

diff --git a/sos/plugins/ipvs.py b/sos/plugins/ipvs.py
new file mode 100644
index 0000000..0513fec
--- /dev/null
+++ b/sos/plugins/ipvs.py
@@ -0,0 +1,28 @@
+## Copyright (C) 2014 Red Hat, Inc. Bryn M. Reeves <bmr@redhat.com>
+### This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+import sos.plugintools
+
+class Ipvs(sos.plugintools.PluginBase):
+    """Ipvs information
+    """
+
+    packages = ('ipvsadm',)
+
+    def setup(self):
+        self.collectExtProg("ipvsadm -Ln")
+        self.collectExtProg("ipvsadm -Lc")
+
+# vim: et ts=4 sw=4
diff --git a/sos/plugins/keepalived.py b/sos/plugins/keepalived.py
index e79778c..4c582b0 100644
--- a/sos/plugins/keepalived.py
+++ b/sos/plugins/keepalived.py
@@ -1,4 +1,3 @@
-## Copyright (C) 2014 Red Hat, Inc. Jamie Bainbridge <jbainbri@redhat.com>
 ## Copyright (C) 2014 Red Hat, Inc. Bryn M. Reeves <bmr@redhat.com>
 ### This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -14,20 +13,16 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-from sos.plugins import Plugin, RedHatPlugin
+import sos.plugintools
 
-class Keepalived(Plugin, RedHatPlugin):
+class keepalived(sos.plugintools.PluginBase):
     """Keepalived information
     """
 
-    plugin_name = 'keepalived'
-
     packages = ('keepalived',)
 
     def setup(self):
-        self.add_copy_specs([
-            "/etc/keepalived/keepalived.conf",
-            "/etc/sysconfig/keepalived"
-        ])
+        self.addCopySpec("/etc/keepalived/keepalived.conf")
+        self.addCopySpec("/etc/sysconfig/keepalived")
 
 # vim: et ts=4 sw=4
-- 
1.9.3

From 1081db7d1cf6317b698a5eb443fbb140e3aed8ef Mon Sep 17 00:00:00 2001
From: "Bryn M. Reeves" <bmr@redhat.com>
Date: Thu, 19 Jun 2014 12:11:14 +0100
Subject: [PATCH 14/17] [ipvs] fix typo and class name in ipvs plugin

---
 sos/plugins/ipvs.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/sos/plugins/ipvs.py b/sos/plugins/ipvs.py
index 0513fec..abe516a 100644
--- a/sos/plugins/ipvs.py
+++ b/sos/plugins/ipvs.py
@@ -15,14 +15,14 @@
 
 import sos.plugintools
 
-class Ipvs(sos.plugintools.PluginBase):
+class ipvs(sos.plugintools.PluginBase):
     """Ipvs information
     """
 
     packages = ('ipvsadm',)
 
     def setup(self):
-        self.collectExtProg("ipvsadm -Ln")
-        self.collectExtProg("ipvsadm -Lc")
+        self.collectExtOutput("ipvsadm -Ln")
+        self.collectExtOutput("ipvsadm -Lc")
 
 # vim: et ts=4 sw=4
-- 
1.9.3

